@@ -3,7 +3,8 @@ package DuckCurses::entity;
 sub new {
 	my ($class, $x,$y, $chr) = @_;
 	my $self = { x => $x, y => $y,
-		mychar => $chr or 'd', 
+		character => $chr or 'o',
+		collidable => undef,
 	};
 
 	$class = ref($class) || $class;
@@ -29,4 +30,10 @@ sub jump {
 	### FIXME
 }
 
+sub print_on_screen {
+	my ($self, $roomx, $roomy) = @_;
+
+	### FIXME
+
+}
 1;
